@@ -10,7 +10,19 @@ Scheduling utility methods and classes.
 import sys
 import time
 import warnings
-from typing import Any, Callable
+from typing import (
+    Callable,
+    Coroutine,
+    Iterable,
+    Iterator,
+    List,
+    NoReturn,
+    Optional,
+    Sequence,
+    TypeVar,
+    Union,
+    cast,
+)
 
 from zope.interface import implementer
 
@@ -20,11 +32,15 @@ from twisted.python.deprecate import _getDeprecationWarningString
 from twisted.python.failure import Failure
 from incremental import Version
 
-from twisted.internet import base, defer
-from twisted.internet.interfaces import IReactorTime
+from twisted.internet.base import DelayedCall
+from twisted.internet.defer import Deferred, ensureDeferred, maybeDeferred
+from twisted.internet.interfaces import IDelayedCall, IReactorCore, IReactorTime
 from twisted.internet.error import ReactorNotRunning
 
 
+_T = TypeVar("_T")
+
+
 class LoopingCall:
     """Call a function repeatedly.
 
@@ -40,39 +56,37 @@ class LoopingCall:
         something else, but it probably ought to be set *before*
         calling L{start}.
 
-    @type running: C{bool}
     @ivar running: A flag which is C{True} while C{f} is scheduled to be called
         (or is currently being called). It is set to C{True} when L{start} is
         called and set to C{False} when L{stop} is called or if C{f} raises an
         exception. In either case, it will be C{False} by the time the
         C{Deferred} returned by L{start} fires its callback or errback.
 
-    @type _realLastTime: C{float}
     @ivar _realLastTime: When counting skips, the time at which the skip
         counter was last invoked.
 
-    @type _runAtStart: C{bool}
     @ivar _runAtStart: A flag indicating whether the 'now' argument was passed
         to L{LoopingCall.start}.
     """
 
-    call = None
+    call: Optional[IDelayedCall] = None
     running = False
-    _deferred = None
-    interval = None
+    _deferred: Optional[Deferred["LoopingCall"]] = None
+    interval: Optional[float] = None
     _runAtStart = False
-    starttime = None
+    starttime: Optional[float] = None
+    _realLastTime: Optional[float] = None
 
-    def __init__(self, f, *a, **kw):
+    def __init__(self, f: Callable[..., object], *a: object, **kw: object) -> None:
         self.f = f
         self.a = a
         self.kw = kw
         from twisted.internet import reactor
 
-        self.clock = reactor
+        self.clock = cast(IReactorTime, reactor)
 
     @property
-    def deferred(self):
+    def deferred(self) -> Optional[Deferred["LoopingCall"]]:
         """
         DEPRECATED. L{Deferred} fired when loop stops or fails.
 
@@ -88,7 +102,7 @@ class LoopingCall:
         return self._deferred
 
     @classmethod
-    def withCount(cls, countCallable):
+    def withCount(cls, countCallable: Callable[[int], object]) -> "LoopingCall":
         """
         An alternate constructor for L{LoopingCall} that makes available the
         number of calls which should have occurred since it was last invoked.
@@ -104,23 +118,19 @@ class LoopingCall:
         elapsed, or if the callable itself blocks for longer than an interval,
         preventing I{itself} from being called.
 
-        When running with an interval if 0, count will be always 1.
+        When running with an interval of 0, count will be always 1.
 
         @param countCallable: A callable that will be invoked each time the
             resulting LoopingCall is run, with an integer specifying the number
             of calls that should have been invoked.
 
-        @type countCallable: 1-argument callable which takes an C{int}
-
         @return: An instance of L{LoopingCall} with call counting enabled,
             which provides the count as the first positional argument.
 
-        @rtype: L{LoopingCall}
-
         @since: 9.0
         """
 
-        def counter():
+        def counter() -> object:
             now = self.clock.seconds()
 
             if self.interval == 0:
@@ -129,8 +139,14 @@ class LoopingCall:
 
             lastTime = self._realLastTime
             if lastTime is None:
+                assert (
+                    self.starttime is not None
+                ), "LoopingCall called before it was started"
                 lastTime = self.starttime
                 if self._runAtStart:
+                    assert (
+                        self.interval is not None
+                    ), "Looping call called with None interval"
                     lastTime -= self.interval
             lastInterval = self._intervalOf(lastTime)
             thisInterval = self._intervalOf(now)
@@ -139,13 +155,13 @@ class LoopingCall:
                 self._realLastTime = now
                 return countCallable(count)
 
-        self = cls(counter)
+            return None
 
-        self._realLastTime = None
+        self = cls(counter)
 
         return self
 
-    def _intervalOf(self, t):
+    def _intervalOf(self, t: float) -> int:
         """
         Determine the number of intervals passed as of the given point in
         time.
@@ -156,11 +172,13 @@ class LoopingCall:
         @return: The C{int} number of intervals which have passed as of the
             given point in time.
         """
+        assert self.starttime is not None
+        assert self.interval is not None
         elapsedTime = t - self.starttime
         intervalNum = int(elapsedTime / self.interval)
         return intervalNum
 
-    def start(self, interval, now=True):
+    def start(self, interval: float, now: bool = True) -> Deferred["LoopingCall"]:
         """
         Start running function every interval seconds.
 
@@ -182,7 +200,7 @@ class LoopingCall:
         self.running = True
         # Loop might fail to start and then self._deferred will be cleared.
         # This why the local C{deferred} variable is used.
-        deferred = self._deferred = defer.Deferred()
+        deferred = self._deferred = Deferred()
         self.starttime = self.clock.seconds()
         self.interval = interval
         self._runAtStart = now
@@ -192,7 +210,7 @@ class LoopingCall:
             self._scheduleFrom(self.starttime)
         return deferred
 
-    def stop(self):
+    def stop(self) -> None:
         """Stop running function."""
         assert self.running, "Tried to stop a LoopingCall that was " "not running."
         self.running = False
@@ -200,9 +218,10 @@ class LoopingCall:
             self.call.cancel()
             self.call = None
             d, self._deferred = self._deferred, None
+            assert d is not None
             d.callback(self)
 
-    def reset(self):
+    def reset(self) -> None:
         """
         Skip the next iteration and reset the timer.
 
@@ -215,32 +234,34 @@ class LoopingCall:
             self.starttime = self.clock.seconds()
             self._scheduleFrom(self.starttime)
 
-    def __call__(self):
-        def cb(result):
+    def __call__(self) -> None:
+        def cb(result: object) -> None:
             if self.running:
                 self._scheduleFrom(self.clock.seconds())
             else:
                 d, self._deferred = self._deferred, None
+                assert d is not None
                 d.callback(self)
 
-        def eb(failure):
+        def eb(failure: Failure) -> None:
             self.running = False
             d, self._deferred = self._deferred, None
+            assert d is not None
             d.errback(failure)
 
         self.call = None
-        d = defer.maybeDeferred(self.f, *self.a, **self.kw)
+        d = maybeDeferred(self.f, *self.a, **self.kw)
         d.addCallback(cb)
         d.addErrback(eb)
 
-    def _scheduleFrom(self, when):
+    def _scheduleFrom(self, when: float) -> None:
         """
         Schedule the next iteration of this looping call.
 
         @param when: The present time from whence the call is scheduled.
         """
 
-        def howLong():
+        def howLong() -> float:
             # How long should it take until the next invocation of our
             # callable?  Split out into a function because there are multiple
             # places we want to 'return' out of this.
@@ -250,8 +271,10 @@ class LoopingCall:
                 return 0
             # Compute the time until the next interval; how long has this call
             # been running for?
+            assert self.starttime is not None
             runningFor = when - self.starttime
             # And based on that start time, when does the current interval end?
+            assert self.interval is not None
             untilNextInterval = self.interval - (runningFor % self.interval)
             # Now that we know how long it would be, we have to tell if the
             # number is effectively zero.  However, we can't just test against
@@ -270,13 +293,16 @@ class LoopingCall:
         self.call = self.clock.callLater(howLong(), self)
 
     def __repr__(self) -> str:
-        if hasattr(self.f, "__qualname__"):
-            func = self.f.__qualname__
-        elif hasattr(self.f, "__name__"):
-            func = self.f.__name__
-            if hasattr(self.f, "im_class"):
-                func = self.f.im_class.__name__ + "." + func
-        else:
+        # This code should be replaced by a utility function in reflect;
+        # see ticket #6066:
+        func = getattr(self.f, "__qualname__", None)
+        if func is None:
+            func = getattr(self.f, "__name__", None)
+            if func is not None:
+                imClass = getattr(self.f, "im_class", None)
+                if imClass is not None:
+                    func = f"{imClass}.{func}"
+        if func is None:
             func = reflect.safe_repr(self.f)
 
         return "LoopingCall<{!r}>({}, *{}, **{})".format(
@@ -339,20 +365,23 @@ class NotPaused(SchedulerError):
 class _Timer:
     MAX_SLICE = 0.01
 
-    def __init__(self):
+    def __init__(self) -> None:
         self.end = time.time() + self.MAX_SLICE
 
-    def __call__(self):
+    def __call__(self) -> bool:
         return time.time() >= self.end
 
 
 _EPSILON = 0.00000001
 
 
-def _defaultScheduler(x):
+def _defaultScheduler(callable: Callable[[], None]) -> IDelayedCall:
     from twisted.internet import reactor
 
-    return reactor.callLater(_EPSILON, x)
+    return cast(IReactorTime, reactor).callLater(_EPSILON, callable)
+
+
+_TaskResultT = TypeVar("_TaskResultT")
 
 
 class CooperativeTask:
@@ -369,61 +398,56 @@ class CooperativeTask:
     @ivar _cooperator: the L{Cooperator} that this L{CooperativeTask}
         participates in, which is used to re-insert it upon resume.
 
-    @ivar _deferreds: the list of L{defer.Deferred}s to fire when this task
+    @ivar _deferreds: the list of L{Deferred}s to fire when this task
         completes, fails, or finishes.
 
-    @type _deferreds: C{list}
-
-    @type _cooperator: L{Cooperator}
-
     @ivar _pauseCount: the number of times that this L{CooperativeTask} has
         been paused; if 0, it is running.
 
-    @type _pauseCount: C{int}
-
     @ivar _completionState: The completion-state of this L{CooperativeTask}.
         L{None} if the task is not yet completed, an instance of L{TaskStopped}
         if C{stop} was called to stop this task early, of L{TaskFailed} if the
         application code in the iterator raised an exception which caused it to
         terminate, and of L{TaskDone} if it terminated normally via raising
         C{StopIteration}.
-
-    @type _completionState: L{TaskFinished}
     """
 
-    def __init__(self, iterator, cooperator):
+    def __init__(
+        self, iterator: Iterator[_TaskResultT], cooperator: "Cooperator"
+    ) -> None:
         """
         A private constructor: to create a new L{CooperativeTask}, see
         L{Cooperator.cooperate}.
         """
         self._iterator = iterator
         self._cooperator = cooperator
-        self._deferreds = []
+        self._deferreds: List[Deferred[Iterator[_TaskResultT]]] = []
         self._pauseCount = 0
-        self._completionState = None
-        self._completionResult = None
+        self._completionState: Optional[SchedulerError] = None
+        self._completionResult: Optional[Union[Iterator[_TaskResultT], Failure]] = None
         cooperator._addTask(self)
 
-    def whenDone(self):
+    def whenDone(self) -> Deferred[Iterator[_TaskResultT]]:
         """
-        Get a L{defer.Deferred} notification of when this task is complete.
+        Get a L{Deferred} notification of when this task is complete.
 
-        @return: a L{defer.Deferred} that fires with the C{iterator} that this
+        @return: a L{Deferred} that fires with the C{iterator} that this
             L{CooperativeTask} was created with when the iterator has been
             exhausted (i.e. its C{next} method has raised C{StopIteration}), or
             fails with the exception raised by C{next} if it raises some other
             exception.
 
-        @rtype: L{defer.Deferred}
+        @rtype: L{Deferred}
         """
-        d = defer.Deferred()
+        d: Deferred[Iterator[_TaskResultT]] = Deferred()
         if self._completionState is None:
             self._deferreds.append(d)
         else:
+            assert self._completionResult is not None
             d.callback(self._completionResult)
         return d
 
-    def pause(self):
+    def pause(self) -> None:
         """
         Pause this L{CooperativeTask}.  Stop doing work until
         L{CooperativeTask.resume} is called.  If C{pause} is called more than
@@ -437,7 +461,7 @@ class CooperativeTask:
         if self._pauseCount == 1:
             self._cooperator._removeTask(self)
 
-    def resume(self):
+    def resume(self) -> None:
         """
         Resume processing of a paused L{CooperativeTask}.
 
@@ -449,9 +473,13 @@ class CooperativeTask:
         if self._pauseCount == 0 and self._completionState is None:
             self._cooperator._addTask(self)
 
-    def _completeWith(self, completionState, deferredResult):
+    def _completeWith(
+        self,
+        completionState: SchedulerError,
+        deferredResult: Union[Iterator[_TaskResultT], Failure],
+    ) -> None:
         """
-        @param completionState: a L{TaskFinished} exception or a subclass
+        @param completionState: a L{SchedulerError} exception or a subclass
             thereof, indicating what exception should be raised when subsequent
             operations are performed.
 
@@ -472,7 +500,7 @@ class CooperativeTask:
         for d in self._deferreds:
             d.callback(deferredResult)
 
-    def stop(self):
+    def stop(self) -> None:
         """
         Stop further processing of this task.
 
@@ -482,7 +510,7 @@ class CooperativeTask:
         self._checkFinish()
         self._completeWith(TaskStopped(), Failure(TaskStopped()))
 
-    def _checkFinish(self):
+    def _checkFinish(self) -> None:
         """
         If this task has been stopped, raise the appropriate subclass of
         L{TaskFinished}.
@@ -490,11 +518,11 @@ class CooperativeTask:
         if self._completionState is not None:
             raise self._completionState
 
-    def _oneWorkUnit(self):
+    def _oneWorkUnit(self) -> None:
         """
         Perform one unit of work for this task, retrieving one item from its
         iterator, stopping if there are no further items in the iterator, and
-        pausing if the result was a L{defer.Deferred}.
+        pausing if the result was a L{Deferred}.
         """
         try:
             result = next(self._iterator)
@@ -503,11 +531,11 @@ class CooperativeTask:
         except BaseException:
             self._completeWith(TaskFailed(), Failure())
         else:
-            if isinstance(result, defer.Deferred):
+            if isinstance(result, Deferred):
                 self.pause()
 
-                def failLater(f):
-                    self._completeWith(TaskFailed(), f)
+                def failLater(failure: Failure) -> None:
+                    self._completeWith(TaskFailed(), failure)
 
                 result.addCallbacks(lambda result: self.resume(), failLater)
 
@@ -519,8 +547,8 @@ class Cooperator:
     A cooperative task is an iterator where each iteration represents an
     atomic unit of work.  When the iterator yields, it allows the
     L{Cooperator} to decide which of its tasks to execute next.  If the
-    iterator yields a L{defer.Deferred} then work will pause until the
-    L{defer.Deferred} fires and completes its callback chain.
+    iterator yields a L{Deferred} then work will pause until the
+    L{Deferred} fires and completes its callback chain.
 
     When a L{Cooperator} has more than one task, it distributes work between
     all tasks.
@@ -530,14 +558,14 @@ class Cooperator:
     L{CooperativeTask}, which can be L{paused<CooperativeTask.pause>},
     L{resumed<CooperativeTask.resume>} and L{waited
     on<CooperativeTask.whenDone>}.  L{coiterate} has the same effect, but
-    returns only a L{defer.Deferred} that fires when the task is done.
+    returns only a L{Deferred} that fires when the task is done.
 
     L{Cooperator} can be used for many things, including but not limited to:
 
       - running one or more computationally intensive tasks without blocking
       - limiting parallelism by running a subset of the total tasks
         simultaneously
-      - doing one thing, waiting for a L{Deferred<defer.Deferred>} to fire,
+      - doing one thing, waiting for a L{Deferred} to fire,
         doing the next thing, repeat (i.e. serializing a sequence of
         asynchronous tasks)
 
@@ -547,9 +575,9 @@ class Cooperator:
 
     def __init__(
         self,
-        terminationPredicateFactory=_Timer,
-        scheduler=_defaultScheduler,
-        started=True,
+        terminationPredicateFactory: Callable[[], Callable[[], bool]] = _Timer,
+        scheduler: Callable[[Callable[[], None]], IDelayedCall] = _defaultScheduler,
+        started: bool = True,
     ):
         """
         Create a scheduler-like object to which iterators may be added.
@@ -568,20 +596,24 @@ class Cooperator:
         stepped as soon as they are added, or if they will be queued up until
         L{Cooperator.start} is called.
         """
-        self._tasks = []
-        self._metarator = iter(())
+        self._tasks: List[CooperativeTask] = []
+        self._metarator: Iterator[CooperativeTask] = iter(())
         self._terminationPredicateFactory = terminationPredicateFactory
         self._scheduler = scheduler
-        self._delayedCall = None
+        self._delayedCall: Optional[IDelayedCall] = None
         self._stopped = False
         self._started = started
 
-    def coiterate(self, iterator, doneDeferred=None):
+    def coiterate(
+        self,
+        iterator: Iterator[_TaskResultT],
+        doneDeferred: Optional[Deferred[Iterator[_TaskResultT]]] = None,
+    ) -> Deferred[Iterator[_TaskResultT]]:
         """
         Add an iterator to the list of iterators this L{Cooperator} is
         currently running.
 
-        Equivalent to L{cooperate}, but returns a L{defer.Deferred} that will
+        Equivalent to L{cooperate}, but returns a L{Deferred} that will
         be fired when the task is done.
 
         @param doneDeferred: If specified, this will be the Deferred used as
@@ -591,11 +623,11 @@ class Cooperator:
         @return: a Deferred that will fire when the iterator finishes.
         """
         if doneDeferred is None:
-            doneDeferred = defer.Deferred()
+            doneDeferred = Deferred()
         CooperativeTask(iterator, self).whenDone().chainDeferred(doneDeferred)
         return doneDeferred
 
-    def cooperate(self, iterator):
+    def cooperate(self, iterator: Iterator[_TaskResultT]) -> CooperativeTask:
         """
         Start running the given iterator as a long-running cooperative task, by
         calling next() on it as a periodic timed event.
@@ -606,7 +638,7 @@ class Cooperator:
         """
         return CooperativeTask(iterator, self)
 
-    def _addTask(self, task):
+    def _addTask(self, task: CooperativeTask) -> None:
         """
         Add a L{CooperativeTask} object to this L{Cooperator}.
         """
@@ -618,7 +650,7 @@ class Cooperator:
             self._tasks.append(task)
             self._reschedule()
 
-    def _removeTask(self, task):
+    def _removeTask(self, task: CooperativeTask) -> None:
         """
         Remove a L{CooperativeTask} from this L{Cooperator}.
         """
@@ -628,7 +660,7 @@ class Cooperator:
             self._delayedCall.cancel()
             self._delayedCall = None
 
-    def _tasksWhileNotStopped(self):
+    def _tasksWhileNotStopped(self) -> Iterable[CooperativeTask]:
         """
         Yield all L{CooperativeTask} objects in a loop as long as this
         L{Cooperator}'s termination condition has not been met.
@@ -641,7 +673,7 @@ class Cooperator:
                     return
             self._metarator = iter(self._tasks)
 
-    def _tick(self):
+    def _tick(self) -> None:
         """
         Run one scheduler tick.
         """
@@ -652,14 +684,14 @@ class Cooperator:
 
     _mustScheduleOnStart = False
 
-    def _reschedule(self):
+    def _reschedule(self) -> None:
         if not self._started:
             self._mustScheduleOnStart = True
             return
         if self._delayedCall is None and self._tasks:
             self._delayedCall = self._scheduler(self._tick)
 
-    def start(self):
+    def start(self) -> None:
         """
         Begin scheduling steps.
         """
@@ -669,7 +701,7 @@ class Cooperator:
             del self._mustScheduleOnStart
             self._reschedule()
 
-    def stop(self):
+    def stop(self) -> None:
         """
         Stop scheduling steps.  Errback the completion Deferreds of all
         iterators which have been added and forget about them.
@@ -683,7 +715,7 @@ class Cooperator:
             self._delayedCall = None
 
     @property
-    def running(self):
+    def running(self) -> bool:
         """
         Is this L{Cooperator} is currently running?
 
@@ -696,7 +728,7 @@ class Cooperator:
 _theCooperator = Cooperator()
 
 
-def coiterate(iterator):
+def coiterate(iterator: Iterator[_T]) -> Deferred[Iterator[_T]]:
     """
     Cooperatively iterate over the given iterator, dividing runtime between it
     and all other iterators which have been passed to this function and not yet
@@ -709,7 +741,7 @@ def coiterate(iterator):
     return _theCooperator.coiterate(iterator)
 
 
-def cooperate(iterator):
+def cooperate(iterator: Iterator[_T]) -> CooperativeTask:
     """
     Start running the given iterator as a long-running cooperative task, by
     calling next() on it as a periodic timed event.
@@ -737,31 +769,32 @@ class Clock:
 
     rightNow = 0.0
 
-    def __init__(self):
-        self.calls = []
+    def __init__(self) -> None:
+        self.calls: List[DelayedCall] = []
 
-    def seconds(self):
+    def seconds(self) -> float:
         """
         Pretend to be time.time().  This is used internally when an operation
         such as L{IDelayedCall.reset} needs to determine a time value
         relative to the current time.
 
-        @rtype: C{float}
         @return: The time which should be considered the current time.
         """
         return self.rightNow
 
-    def _sortCalls(self):
+    def _sortCalls(self) -> None:
         """
         Sort the pending calls according to the time they are scheduled.
         """
         self.calls.sort(key=lambda a: a.getTime())
 
-    def callLater(self, delay, callable: Callable[..., Any], *args, **kw):
+    def callLater(
+        self, delay: float, callable: Callable[..., object], *args: object, **kw: object
+    ) -> IDelayedCall:
         """
         See L{twisted.internet.interfaces.IReactorTime.callLater}.
         """
-        dc = base.DelayedCall(
+        dc = DelayedCall(
             self.seconds() + delay,
             callable,
             args,
@@ -774,18 +807,17 @@ class Clock:
         self._sortCalls()
         return dc
 
-    def getDelayedCalls(self):
+    def getDelayedCalls(self) -> Sequence[IDelayedCall]:
         """
         See L{twisted.internet.interfaces.IReactorTime.getDelayedCalls}
         """
         return self.calls
 
-    def advance(self, amount):
+    def advance(self, amount: float) -> None:
         """
         Move time on this clock forward by the given amount and run whatever
         pending calls should be run.
 
-        @type amount: C{float}
         @param amount: The number of seconds which to advance this clock's
         time.
         """
@@ -797,50 +829,61 @@ class Clock:
             call.func(*call.args, **call.kw)
             self._sortCalls()
 
-    def pump(self, timings):
+    def pump(self, timings: Iterable[float]) -> None:
         """
         Advance incrementally by the given set of times.
-
-        @type timings: iterable of C{float}
         """
         for amount in timings:
             self.advance(amount)
 
 
-def deferLater(clock, delay, callable=None, *args, **kw):
+def deferLater(
+    clock: IReactorTime,
+    delay: float,
+    callable: Optional[Callable[..., _T]] = None,
+    *args: object,
+    **kw: object,
+) -> Deferred[_T]:
     """
     Call the given function after a certain period of time has passed.
 
-    @type clock: L{IReactorTime} provider
     @param clock: The object which will be used to schedule the delayed
         call.
 
-    @type delay: C{float} or C{int}
     @param delay: The number of seconds to wait before calling the function.
 
-    @param callable: The object to call after the delay.
+    @param callable: The callable to call after the delay, or C{None}.
 
     @param args: The positional arguments to pass to C{callable}.
 
     @param kw: The keyword arguments to pass to C{callable}.
 
-    @rtype: L{defer.Deferred}
-
     @return: A deferred that fires with the result of the callable when the
         specified time has elapsed.
     """
 
-    def deferLaterCancel(deferred):
+    def deferLaterCancel(deferred: Deferred[object]) -> None:
         delayedCall.cancel()
 
-    d = defer.Deferred(deferLaterCancel)
-    if callable is not None:
-        d.addCallback(lambda ignored: callable(*args, **kw))
+    def cb(result: object) -> _T:
+        if callable is None:
+            return None  # type: ignore[return-value]
+        return callable(*args, **kw)
+
+    d: Deferred[_T] = Deferred(deferLaterCancel)
+    d.addCallback(cb)
     delayedCall = clock.callLater(delay, d.callback, None)
     return d
 
 
-def react(main, argv=(), _reactor=None):
+def react(
+    main: Callable[
+        ...,
+        Union[Deferred[_T], Coroutine["Deferred[_T]", object, _T]],
+    ],
+    argv: Iterable[_T] = (),
+    _reactor: Optional[IReactorCore] = None,
+) -> NoReturn:
     """
     Call C{main} and run the reactor until the L{Deferred} it returns fires or
     the coroutine it returns completes.
@@ -877,37 +920,47 @@ def react(main, argv=(), _reactor=None):
     @since: 12.3
     """
     if _reactor is None:
-        from twisted.internet import reactor as _reactor
-    finished = defer.ensureDeferred(main(_reactor, *argv))
-    codes = [0]
+        from twisted.internet import reactor
 
-    stopping = []
-    _reactor.addSystemEventTrigger("before", "shutdown", stopping.append, True)
+        _reactor = cast(IReactorCore, reactor)
 
-    def stop(result, stopReactor):
+    finished = ensureDeferred(main(_reactor, *argv))
+    code = 0
+
+    stopping = False
+
+    def onShutdown() -> None:
+        nonlocal stopping
+        stopping = True
+
+    _reactor.addSystemEventTrigger("before", "shutdown", onShutdown)
+
+    def stop(result: object, stopReactor: bool) -> None:
         if stopReactor:
+            assert _reactor is not None
             try:
                 _reactor.stop()
             except ReactorNotRunning:
                 pass
 
         if isinstance(result, Failure):
+            nonlocal code
             if result.check(SystemExit) is not None:
                 code = result.value.code
             else:
                 log.err(result, "main function encountered error")
                 code = 1
-            codes[0] = code
 
-    def cbFinish(result):
+    def cbFinish(result: object) -> None:
         if stopping:
             stop(result, False)
         else:
+            assert _reactor is not None
             _reactor.callWhenRunning(stop, result, True)
 
     finished.addBoth(cbFinish)
     _reactor.run()
-    sys.exit(codes[0])
+    sys.exit(code)
 
 
 __all__ = [
