@@ -7,13 +7,11 @@ Tests for L{twisted.logger._json}.
 
 from io import StringIO, BytesIO
 from typing import Any, IO, List, Optional, Sequence, cast
-from unittest import skipIf
 
 from zope.interface import implementer
 from zope.interface.exceptions import BrokenMethodImplementation
 from zope.interface.verify import verifyObject
 
-from twisted.python.compat import _PYPY
 from twisted.python.failure import Failure
 from twisted.trial.unittest import TestCase
 
@@ -102,7 +100,6 @@ class SaveLoadTests(TestCase):
             {"\u1234": "\u4321", "3": {"unpersistable": True}},
         )
 
-    @skipIf(_PYPY, "https://bitbucket.org/pypy/pypy/issues/3052/")
     def test_saveBytes(self) -> None:
         """
         Any L{bytes} objects will be saved as if they are latin-1 so they can
@@ -162,7 +159,7 @@ class SaveLoadTests(TestCase):
         Round-tripping a failure through L{eventAsJSON} preserves its class and
         structure.
         """
-        events = []  # type: List[LogEvent]
+        events: List[LogEvent] = []
         log = Logger(observer=cast(ILogObserver, events.append))
         try:
             1 / 0
@@ -226,9 +223,7 @@ class FileLogObserverTests(TestCase):
             observer = jsonFileLogObserver(fileHandle, recordSeparator)
             event = dict(x=1)
             observer(event)
-            self.assertEqual(
-                fileHandle.getvalue(), '{0}{{"x": 1}}\n'.format(recordSeparator)
-            )
+            self.assertEqual(fileHandle.getvalue(), f'{recordSeparator}{{"x": 1}}\n')
 
     def test_observeWritesDefaultRecordSeparator(self) -> None:
         """
@@ -253,7 +248,7 @@ class FileLogObserverTests(TestCase):
         """
         io = StringIO()
         publisher = LogPublisher()
-        logged = []  # type: List[LogEvent]
+        logged: List[LogEvent] = []
         publisher.addObserver(cast(ILogObserver, logged.append))
         publisher.addObserver(jsonFileLogObserver(io))
         logger = Logger(observer=publisher)
@@ -286,7 +281,7 @@ class LogFileReaderTests(TestCase):
     """
 
     def setUp(self) -> None:
-        self.errorEvents = []  # type: List[LogEvent]
+        self.errorEvents: List[LogEvent] = []
 
         @implementer(ILogObserver)
         def observer(event: LogEvent) -> None:
