@@ -10,7 +10,7 @@ Utilities and helpers for simulating a network
 import itertools
 
 try:
-    from OpenSSL.SSL import Error as NativeOpenSSLError
+    from OpenSSL.SSL import Error as NativeOpenSSLError  # type: ignore[import]
 except ImportError:
     pass
 
@@ -33,7 +33,7 @@ class TLSNegotiation:
         self.readyToSend = connectState
 
     def __repr__(self) -> str:
-        return "TLSNegotiation({!r})".format(self.obj)
+        return f"TLSNegotiation({self.obj!r})"
 
     def pretendToVerify(self, other, tpt):
         # Set the transport problems list here?  disconnections?
