@@ -203,7 +203,7 @@ class File(resource.Resource, filepath.FilePath):
 
     contentEncodings = {".gz": "gzip", ".bz2": "bzip2"}
 
-    processors = {}  # type: Dict[str, Callable[[str, Any], Data]]
+    processors: Dict[str, Callable[[str, Any], Data]] = {}
 
     indexNames = ["index", "index.html", "index.htm", "index.rpy"]
 
@@ -301,9 +301,7 @@ class File(resource.Resource, filepath.FilePath):
                 # leaving us with raw bytes.
                 path = path.decode("utf-8")
             except UnicodeDecodeError:
-                log.err(
-                    None, "Could not decode path segment as utf-8: {!r}".format(path)
-                )
+                log.err(None, f"Could not decode path segment as utf-8: {path!r}")
                 return self.childNotFound
 
         self.restat(reraise=False)
@@ -364,36 +362,36 @@ class File(resource.Resource, filepath.FilePath):
             raise ValueError("Missing '=' separator")
         kind = kind.strip()
         if kind != b"bytes":
-            raise ValueError("Unsupported Bytes-Unit: {!r}".format(kind))
+            raise ValueError(f"Unsupported Bytes-Unit: {kind!r}")
         unparsedRanges = list(filter(None, map(bytes.strip, value.split(b","))))
         parsedRanges = []
         for byteRange in unparsedRanges:
             try:
                 start, end = byteRange.split(b"-", 1)
             except ValueError:
-                raise ValueError("Invalid Byte-Range: {!r}".format(byteRange))
+                raise ValueError(f"Invalid Byte-Range: {byteRange!r}")
             if start:
                 try:
                     start = int(start)
                 except ValueError:
-                    raise ValueError("Invalid Byte-Range: {!r}".format(byteRange))
+                    raise ValueError(f"Invalid Byte-Range: {byteRange!r}")
             else:
                 start = None
             if end:
                 try:
                     end = int(end)
                 except ValueError:
-                    raise ValueError("Invalid Byte-Range: {!r}".format(byteRange))
+                    raise ValueError(f"Invalid Byte-Range: {byteRange!r}")
             else:
                 end = None
             if start is not None:
                 if end is not None and start > end:
                     # Start must be less than or equal to end or it is invalid.
-                    raise ValueError("Invalid Byte-Range: {!r}".format(byteRange))
+                    raise ValueError(f"Invalid Byte-Range: {byteRange!r}")
             elif end is None:
                 # One or both of start and end must be specified.  Omitting
                 # both is invalid.
-                raise ValueError("Invalid Byte-Range: {!r}".format(byteRange))
+                raise ValueError(f"Invalid Byte-Range: {byteRange!r}")
             parsedRanges.append((start, end))
         return parsedRanges
 
@@ -604,7 +602,7 @@ class File(resource.Resource, filepath.FilePath):
         try:
             parsedRanges = self._parseRangeHeader(byteRange)
         except ValueError:
-            log.msg("Ignoring malformed Range header {!r}".format(byteRange.decode()))
+            log.msg(f"Ignoring malformed Range header {byteRange.decode()!r}")
             self._setContentHeaders(request)
             request.setResponseCode(http.OK)
             return NoRangeStaticProducer(request, fileForReading)
